@@ -1,15 +1,17 @@
 from django.http import QueryDict
 from django.utils import simplejson
 
+from .utils.emitter import JSONPEmitter, JSONEmitter
+from .utils.exceptions import HttpError
+from .utils.status import HTTP_402_PAYMENT_REQUIRED
 from .views import ResourceView
-from adrest.utils.exceptions import HttpError
-from adrest.utils.status import HTTP_402_PAYMENT_REQUIRED
 
 
 class RPCResource(ResourceView):
     " Auto generated RPC. "
 
     url_regex = r'^rpc$'
+    emitters = JSONEmitter, JSONPEmitter
 
     SEPARATOR = '.'
 
